Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7521)

Unified Diff: chrome/browser/ui/autofill/autofill_popup_controller.h

Issue 2727233003: Uses child views in Autofill Popup so we can trigger (Closed)
Patch Set: Combines 2 calls to InvalidateRow to 1 OnSelectedRowChanged call. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_popup_controller.h
diff --git a/chrome/browser/ui/autofill/autofill_popup_controller.h b/chrome/browser/ui/autofill/autofill_popup_controller.h
index c9aec43f61bde65157c3d88dd5d74b8f0c8a022a..e9f8d4aae48cd33ef03429d49102854babe02a29 100644
--- a/chrome/browser/ui/autofill/autofill_popup_controller.h
+++ b/chrome/browser/ui/autofill/autofill_popup_controller.h
@@ -24,8 +24,9 @@ struct Suggestion;
// This interface provides data to an AutofillPopupView.
class AutofillPopupController : public AutofillPopupViewDelegate {
public:
- // Recalculates the height and width of the popup and triggers a redraw.
- virtual void UpdateBoundsAndRedrawPopup() = 0;
+ // Recalculates the height and width of the popup and triggers a redraw when
+ // suggestions change.
+ virtual void OnSuggestionsChanged() = 0;
// Accepts the suggestion at |index|.
virtual void AcceptSuggestion(size_t index) = 0;

Powered by Google App Engine
This is Rietveld 408576698